Modules
Macros
Structs
- Complete
Unit Properties Call Params - Dependency
- Systemd
Signal Row - Systemd
Unit File - Unit
Properties - Unit
Property Fetch - Updated
Unit Info
Enums
Functions
- clean_
unit - commander_
output - complete_
single_ unit_ information - complete_
unit_ information - create_
drop_ in - daemon_
reload - disable_
unit_ file - disenable_
unit_ file - enable_
unit_ file - fetch_
drop_ in_ paths - fetch_
last_ time - fetch_
system_ info - fetch_
system_ unit_ info_ native - fetch_
system_ unit_ info_ native_ map - fetch_
unit - fetch_
unit_ dependencies - fetch_
unit_ file_ content - Read the unit file and return it’s contents so that we can display it
- fetch_
unit_ interface_ properties - fetch_
unit_ properties - fetch_
unit_ property_ blocking - fill_
list_ unit_ files - freeze_
unit - generate_
file_ uri - get_
unit_ active_ state - get_
unit_ file_ state - Returns the current enablement status of the unit
- get_
unit_ journal - Obtains the journal log for the given unit.
- get_
unit_ journal_ continuous - init_
proxy_ async - Try to Start Proxy
- init_
signal_ watcher - kill_
unit - link_
unit_ files - list_
boots - list_
loaded_ units - list_
loaded_ units_ automounts - list_
loaded_ units_ by_ patterns - list_
loaded_ units_ list - list_
loaded_ units_ paths - list_
loaded_ units_ sockets - list_
loaded_ units_ timers - list_
unit_ files - list_
unit_ files_ automounts - list_
unit_ files_ by_ patterns - list_
unit_ files_ list - list_
unit_ files_ paths - list_
unit_ files_ sockets - list_
unit_ files_ timers - list_
units_ description_ and_ state_ async - mask_
unit_ files - preset_
unit_ files - queue_
signal_ unit - reenable_
unit_ file - reload_
unit - restartstop_
unit - retreive_
unit_ processes - revert_
unit_ file_ full - runtime
- save_
file - shut_
down - shut_
down_ sysd_ proxy - start_
unit - Takes a unit name as input and attempts to start it
- stop_
unit - Takes a unit name as input and attempts to stop it.
- sysd_
proxy_ service_ name - test
- thaw_
unit - unmask_
unit_ files