pub struct UnitInfo { /* private fields */ }Expand description
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl UnitInfo
impl UnitInfo
pub fn primary(&self) -> <OnceCell<String> as Property>::Value
pub fn display_name(&self) -> <String as Property>::Value
pub fn unit_type(&self) -> <Cell<UnitType> as Property>::Value
pub fn description(&self) -> <RefCell<Option<String>> as Property>::Value
pub fn set_description<'a>( &self, value: impl Borrow<<<RefCell<Option<String>> as Property>::Value as HasParamSpec>::SetValue>, )
pub fn load_state(&self) -> <Cell<LoadState> as Property>::Value
pub fn set_load_state<'a>( &self, value: impl Borrow<<<Cell<LoadState> as Property>::Value as HasParamSpec>::SetValue>, )
pub fn active_state(&self) -> <Cell<ActiveState> as Property>::Value
pub fn set_active_state<'a>( &self, value: impl Borrow<<<Cell<ActiveState> as Property>::Value as HasParamSpec>::SetValue>, )
pub fn sub_state(&self) -> <RefCell<String> as Property>::Value
pub fn set_sub_state<'a>( &self, value: impl Borrow<<<RefCell<String> as Property>::Value as HasParamSpec>::SetValue>, )
pub fn followed_unit(&self) -> <RefCell<String> as Property>::Value
pub fn object_path(&self) -> <String as Property>::Value
pub fn file_path(&self) -> <RefCell<Option<String>> as Property>::Value
pub fn set_file_path<'a>( &self, value: Option<impl Borrow<<<RefCell<Option<String>> as Property>::Value as HasParamSpec>::SetValue>>, )
pub fn enable_status(&self) -> <Cell<UnitFileStatus> as Property>::Value
pub fn set_enable_status<'a>( &self, value: impl Borrow<<<Cell<UnitFileStatus> as Property>::Value as HasParamSpec>::SetValue>, )
pub fn dbus_level(&self) -> <Cell<UnitDBusLevel> as Property>::Value
pub fn set_dbus_level<'a>( &self, value: impl Borrow<<<Cell<UnitDBusLevel> as Property>::Value as HasParamSpec>::SetValue>, )
pub fn preset(&self) -> <Cell<Preset> as Property>::Value
pub fn set_preset<'a>( &self, value: impl Borrow<<<Cell<Preset> as Property>::Value as HasParamSpec>::SetValue>, )
Sourcepub fn connect_primary_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_primary_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the primary property
Sourcepub fn connect_display_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_display_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the display-name property
Sourcepub fn connect_unit_type_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_unit_type_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the unit-type property
Sourcepub fn connect_description_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_description_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the description property
Sourcepub fn connect_load_state_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_load_state_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the load-state property
Sourcepub fn connect_active_state_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_active_state_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the active-state property
Sourcepub fn connect_sub_state_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_sub_state_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the sub-state property
Sourcepub fn connect_followed_unit_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_followed_unit_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the followed-unit property
Sourcepub fn connect_object_path_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_object_path_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the object-path property
Sourcepub fn connect_file_path_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_file_path_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the file-path property
Sourcepub fn connect_enable_status_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_enable_status_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the enable-status property
Sourcepub fn connect_dbus_level_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_dbus_level_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the dbus-level property
Sourcepub fn connect_preset_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_preset_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the preset property
Sourcepub fn notify_primary(&self)
pub fn notify_primary(&self)
Notify listeners of a change in the primary property
Sourcepub fn notify_display_name(&self)
pub fn notify_display_name(&self)
Notify listeners of a change in the display-name property
Sourcepub fn notify_unit_type(&self)
pub fn notify_unit_type(&self)
Notify listeners of a change in the unit-type property
Sourcepub fn notify_description(&self)
pub fn notify_description(&self)
Notify listeners of a change in the description property
Sourcepub fn notify_load_state(&self)
pub fn notify_load_state(&self)
Notify listeners of a change in the load-state property
Sourcepub fn notify_active_state(&self)
pub fn notify_active_state(&self)
Notify listeners of a change in the active-state property
Sourcepub fn notify_sub_state(&self)
pub fn notify_sub_state(&self)
Notify listeners of a change in the sub-state property
Sourcepub fn notify_followed_unit(&self)
pub fn notify_followed_unit(&self)
Notify listeners of a change in the followed-unit property
Sourcepub fn notify_object_path(&self)
pub fn notify_object_path(&self)
Notify listeners of a change in the object-path property
Sourcepub fn notify_file_path(&self)
pub fn notify_file_path(&self)
Notify listeners of a change in the file-path property
Sourcepub fn notify_enable_status(&self)
pub fn notify_enable_status(&self)
Notify listeners of a change in the enable-status property
Sourcepub fn notify_dbus_level(&self)
pub fn notify_dbus_level(&self)
Notify listeners of a change in the dbus-level property
Sourcepub fn notify_preset(&self)
pub fn notify_preset(&self)
Notify listeners of a change in the preset property
Sourceimpl UnitInfo
impl UnitInfo
pub fn from_listed_unit( listed_unit: ListedLoadedUnit, level: UnitDBusLevel, ) -> Self
pub fn init_from_listed_unit( &self, listed_unit: ListedLoadedUnit, level: UnitDBusLevel, )
pub fn from_unit_file(unit_file: ListedUnitFile, level: UnitDBusLevel) -> Self
pub fn from_unit_key(name: &str, level: UnitDBusLevel) -> Self
pub fn update_from_loaded_unit(&self, listed_unit: ListedLoadedUnit)
pub fn update_from_unit_info(&self, update: UpdatedUnitInfo)
pub fn update_from_unit_file(&self, unit_file: ListedUnitFile)
pub fn debug(&self) -> String
pub fn need_to_be_completed(&self) -> bool
pub fn insert_socket_listen(&self, quark: Quark, value: OwnedValue) -> usize
pub fn insert_unit_property_value(&self, quark: Quark, value: OwnedValue)
pub fn get_custom_property_to_string<T>(&self, key: Quark) -> Option<String>where
T: ToString + 'static,
pub fn get_custom_property<T: 'static>(&self, key: Quark) -> Option<&T>
pub fn display_custom_property(&self, key: Quark) -> Option<String>
pub fn is_template_unit_file(&self) -> bool