pub enum UnitFileStatus {
Show 14 variants
Unknown,
Alias,
Bad,
Disabled,
Enabled,
EnabledRuntime,
Generated,
Indirect,
Linked,
LinkedRuntime,
Masked,
MaskedRuntime,
Static,
Transient,
}Variants
Unknown
Alias
Bad
Disabled
Enabled
EnabledRuntime
Generated
Indirect
Linked
LinkedRuntime
Masked
MaskedRuntime
Static
Transient
Implementations
Sourceimpl UnitFileStatus
impl UnitFileStatus
Sourcepub fn from_strr(enablement_status: &str) -> UnitFileStatus
pub fn from_strr(enablement_status: &str) -> UnitFileStatus
Takes the string containing the state information from the dbus message and converts it into a UnitType by matching the first character.
pub fn as_str(&self) -> &'static str
pub fn label(&self) -> &'static str
pub fn tooltip_info(&self) -> Option<String>
pub fn is_runtime(&self) -> bool
pub fn has_status(&self) -> bool