pub fn stop_unit(
level: UnitDBusLevel,
unit_name: &str,
mode: StartStopMode,
) -> Result<String, SystemdErrors>Expand description
Takes a unit name as input and attempts to stop it.
pub fn stop_unit(
level: UnitDBusLevel,
unit_name: &str,
mode: StartStopMode,
) -> Result<String, SystemdErrors>Takes a unit name as input and attempts to stop it.