pub enum StartStopMode {
Replace,
Fail,
Isolate,
IgnoreDependencies,
IgnoreRequirements,
}Variants
Replace
If “replace” the call will start the unit and its dependencies, possibly replacing already queued jobs that conflict with this.
Fail
If “fail” the call will start the unit and its dependencies, but will fail if this would change an already queued job.
Isolate
If “isolate” the call will start the unit in question and terminate all units that aren’t dependencies of it. Note that “isolate” mode is invalid for method StopUnit.
IgnoreDependencies
If “ignore-dependencies” it will start a unit but ignore all its dependencies.
IgnoreRequirements
If “ignore-requirements” it will start a unit but only ignore the requirement dependencies.
Implementations
Sourceimpl StartStopMode
impl StartStopMode