UnitType

Enum UnitType 

pub enum UnitType {
Show 16 variants Automount, Busname, Device, Manager, Mount, Path, Scope, Service, Slice, Snapshot, Socket, Swap, Target, Timer, Unit, Unknown,
}

Variants



Automount



Busname



Device



Manager



Mount



Path



Scope



Service



Slice



Snapshot



Socket



Swap



Target



Timer



Unit



Unknown

Implementations

Source

impl UnitType

pub fn new(unit_type: &str) -> UnitType

Takes the pathname of the unit as input to determine what type of unit it is.

pub fn as_str(&self) -> &'static str

pub fn interface(&self) -> &str

pub fn from_intreface(interface: &str) -> UnitType