pub struct SocketUnitInfo { /* private fields */ }Expand description
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl SocketUnitInfo
impl SocketUnitInfo
pub fn primary(&self) -> <OnceCell<String> as Property>::Value
pub fn display_name(&self) -> <String as Property>::Value
pub fn unit_type(&self) -> <Cell<UnitType> as Property>::Value
pub fn socket_listen_idx(&self) -> <Cell<u32> as Property>::Value
pub fn dbus_level(&self) -> <Cell<UnitDBusLevel> as Property>::Value
pub fn set_dbus_level<'a>( &self, value: impl Borrow<<<Cell<UnitDBusLevel> as Property>::Value as HasParamSpec>::SetValue>, )
pub fn active_state(&self) -> <ActiveState as Property>::Value
pub fn set_active_state<'a>( &self, value: impl Borrow<<<ActiveState as Property>::Value as HasParamSpec>::SetValue>, )
pub fn object_path(&self) -> <String as Property>::Value
Sourcepub fn connect_primary_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_primary_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the primary property
Sourcepub fn connect_display_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_display_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the display-name property
Sourcepub fn connect_unit_type_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_unit_type_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the unit-type property
Sourcepub fn connect_socket_listen_idx_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_socket_listen_idx_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the socket-listen-idx property
Sourcepub fn connect_dbus_level_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_dbus_level_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the dbus-level property
Sourcepub fn connect_active_state_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_active_state_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the active-state property
Sourcepub fn connect_object_path_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_object_path_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the object-path property
Sourcepub fn notify_primary(&self)
pub fn notify_primary(&self)
Notify listeners of a change in the primary property
Sourcepub fn notify_display_name(&self)
pub fn notify_display_name(&self)
Notify listeners of a change in the display-name property
Sourcepub fn notify_unit_type(&self)
pub fn notify_unit_type(&self)
Notify listeners of a change in the unit-type property
Sourcepub fn notify_socket_listen_idx(&self)
pub fn notify_socket_listen_idx(&self)
Notify listeners of a change in the socket-listen-idx property
Sourcepub fn notify_dbus_level(&self)
pub fn notify_dbus_level(&self)
Notify listeners of a change in the dbus-level property
Sourcepub fn notify_active_state(&self)
pub fn notify_active_state(&self)
Notify listeners of a change in the active-state property
Sourcepub fn notify_object_path(&self)
pub fn notify_object_path(&self)
Notify listeners of a change in the object-path property
Sourceimpl SocketUnitInfo
impl SocketUnitInfo
pub fn from_unit_socket(unit: &UnitInfo, socket_listen_idx: usize) -> Self
pub fn get_parent_qproperty<T: 'static>(&self, key: Quark) -> Option<&T>
pub fn get_parent_qproperty_to_string<T: 'static + ToString>( &self, key: Quark, ) -> Option<String>
pub fn display_custom_property(&self, key: Quark) -> Option<String>